@@ -7,13 +7,13 @@ def str_or_hex(v: bytes) -> str:
     try:
         decoded = v.decode("utf-8")
     except Exception:
-        decoded = f"0x{v.hex()}"
+        decoded = v.hex()
 
     return decoded
 
 
 def decode_state(
-    state: list[dict[str, Any]], force_str=False
+    state: list[dict[str, Any]], raw=False
 ) -> dict[str | bytes, bytes | str | int]:
 
     decoded_state: dict[str | bytes, bytes | str | int] = {}
@@ -22,13 +22,13 @@ def decode_state(
 
         raw_key = b64decode(sv["key"])
 
-        key: str | bytes = str_or_hex(raw_key) if force_str else raw_key
+        key: str | bytes = raw_key if raw else str_or_hex(raw_key)
         val: str | bytes | int
 
         match sv["value"]["type"]:
             case 1:
                 raw_val = b64decode(sv["value"]["bytes"])
-                val = str_or_hex(raw_val) if force_str else raw_val
+                val = raw_val if raw else str_or_hex(raw_val)
             case 2:
                 val = sv["value"]["uint"]
 
