@@ -1,11 +1,10 @@
 import pytest
 import pyteal as pt
 
-from .application import get_method_spec
 from .decorators import (
-    ResolvableArguments,
     external,
     get_handler_config,
+    DefaultArgument,
     Authorize,
     create,
     clear_state,
@@ -19,7 +18,7 @@ from .decorators import (
 options = pt.CompileOptions(mode=pt.Mode.Application, version=pt.MAX_TEAL_VERSION)
 
 
-def test_external_config():
+def test_handler_config():
     @external
     def handleable():
         pass
@@ -96,6 +95,8 @@ def test_external_config():
 
 def test_authorize():
 
+    cmt = "unauthorized"
+
     auth_only = Authorize.only(pt.Global.creator_address())
 
     expr = pt.Txn.sender() == pt.Global.creator_address()
@@ -108,7 +109,7 @@ def test_authorize():
     def creator_only():
         return pt.Approve()
 
-    expr = pt.Seq(pt.Assert(auth_only(pt.Txn.sender())), pt.Approve())
+    expr = pt.Seq(pt.Assert(auth_only(pt.Txn.sender()), comment=cmt), pt.Approve())
 
     expected = expr.__teal__(options)
     actual = creator_only().__teal__(options)
@@ -136,7 +137,9 @@ def test_authorize():
     def holds_token_only():
         return pt.Approve()
 
-    expr = pt.Seq(pt.Assert(auth_holds_token(pt.Txn.sender())), pt.Approve())
+    expr = pt.Seq(
+        pt.Assert(auth_holds_token(pt.Txn.sender()), comment=cmt), pt.Approve()
+    )
 
     expected = expr.__teal__(options)
     actual = holds_token_only().__teal__(options)
@@ -162,11 +165,24 @@ def test_authorize():
     def opted_in_only():
         return pt.Approve()
 
-    expr = pt.Seq(pt.Assert(auth_opted_in(pt.Txn.sender())), pt.Approve())
+    expr = pt.Seq(pt.Assert(auth_opted_in(pt.Txn.sender()), comment=cmt), pt.Approve())
 
     expected = expr.__teal__(options)
     actual = opted_in_only().__teal__(options)
 
+    with pt.TealComponent.Context.ignoreExprEquality():
+        assert actual == expected
+
+    # Bare handler
+
+    @delete(authorize=auth_only)
+    def deleter():
+        return pt.Approve()
+
+    expr = pt.Seq(pt.Assert(auth_only(pt.Txn.sender()), comment=cmt), pt.Approve())
+
+    expected = expr.__teal__(options)
+    actual = deleter().__teal__(options)
     with pt.TealComponent.Context.ignoreExprEquality():
         assert actual == expected
 
@@ -194,6 +210,19 @@ def test_authorize():
             pass
 
 
+def test_named_tuple():
+    class Order(pt.abi.NamedTuple):
+        item: pt.abi.Field[pt.abi.String]
+        count: pt.abi.Field[pt.abi.Uint64]
+
+    @external
+    def thing(o: Order):
+        pass
+
+    hc = get_handler_config(thing)
+    assert hc.structs["o"] is Order
+
+
 def test_bare():
     @create
     def impl():
@@ -249,54 +278,35 @@ def test_resolvable():
     from .state import (
         AccountStateValue,
         ApplicationStateValue,
-        DynamicAccountStateValue,
-        DynamicApplicationStateValue,
+        ReservedAccountStateValue,
+        ReservedApplicationStateValue,
     )
 
     x = AccountStateValue(pt.TealType.uint64, key=pt.Bytes("x"))
-    r = ResolvableArguments(x=x)
-    assert r.x == {"local-state": "x"}
+    r = DefaultArgument(x)
+    assert r.resolvable_class == "local-state"
 
-    x = DynamicAccountStateValue(pt.TealType.uint64, max_keys=1)
-    r = ResolvableArguments(x=x[pt.Bytes("x")])
-    assert r.x == {"local-state": "x"}
+    x = ReservedAccountStateValue(pt.TealType.uint64, max_keys=1)
+    r = DefaultArgument(x[pt.Bytes("x")])
+    assert r.resolvable_class == "local-state"
 
     x = ApplicationStateValue(pt.TealType.uint64, key=pt.Bytes("x"))
-    r = ResolvableArguments(x=x)
-    assert r.x == {"global-state": "x"}
+    r = DefaultArgument(x)
+    assert r.resolvable_class == "global-state"
 
-    x = DynamicApplicationStateValue(pt.TealType.uint64, max_keys=1)
-    r = ResolvableArguments(x=x[pt.Bytes("x")])
-    assert r.x == {"global-state": "x"}
-
-    x = DynamicApplicationStateValue(pt.TealType.uint64, max_keys=1)
-    r = ResolvableArguments(x=x[pt.Bytes("x")])
-    assert r.x == {"global-state": "x"}
+    x = ReservedApplicationStateValue(pt.TealType.uint64, max_keys=1)
+    r = DefaultArgument(x[pt.Bytes("x")])
+    assert r.resolvable_class == "global-state"
 
     @external(read_only=True)
     def x():
         return pt.Assert(pt.Int(1))
 
-    r = ResolvableArguments(x=x)
-    assert r.x == {"abi-method": get_method_spec(x).dictify()}
+    r = DefaultArgument(x)
+    assert r.resolvable_class == "abi-method"
 
-    r = ResolvableArguments(x="1")
-    assert r.x == {"constant": "1"}
+    r = DefaultArgument(pt.Bytes("1"))
+    assert r.resolvable_class == "constant"
 
-    r = ResolvableArguments(x=1)
-    assert r.x == {"constant": 1}
-
-    with pytest.raises(Exception):
-
-        @external(resolvable=ResolvableArguments(x=1))
-        def doit(a: pt.abi.Uint64):
-            pass
-
-    with pytest.raises(Exception):
-
-        @external
-        def x():
-            return pt.Assert(pt.Int(1))
-
-        r = ResolvableArguments(x=x)
-        assert r.x == {"abi-method": get_method_spec(x).dictify()}
+    r = DefaultArgument(pt.Int(1))
+    assert r.resolvable_class == "constant"
